@@ -12,7 +12,10 @@ CREATE TABLE presentity (
     CONSTRAINT presentity_presentity_idx UNIQUE (username, domain, event, etag)
 );
 
-INSERT INTO version (table_name, table_version) values ('active_watchers','9');
+CREATE INDEX presentity_presentity_expires ON presentity (expires);
+CREATE INDEX presentity_account_idx ON presentity (username, domain, event);
+
+INSERT INTO version (table_name, table_version) values ('active_watchers','11');
 CREATE TABLE active_watchers (
     id SERIAL PRIMARY KEY NOT NULL,
     presentity_uri VARCHAR(128) NOT NULL,
@@ -35,9 +38,18 @@ CREATE TABLE active_watchers (
     version INTEGER DEFAULT 0 NOT NULL,
     socket_info VARCHAR(64) NOT NULL,
     local_contact VARCHAR(128) NOT NULL,
-    CONSTRAINT active_watchers_active_watchers_idx UNIQUE (presentity_uri, callid, to_tag, from_tag)
+    from_user VARCHAR(64) NOT NULL,
+    from_domain VARCHAR(64) NOT NULL,
+    updated INTEGER NOT NULL,
+    updated_winfo INTEGER NOT NULL,
+    CONSTRAINT active_watchers_active_watchers_idx UNIQUE (callid, to_tag, from_tag)
 );
 
+CREATE INDEX active_watchers_active_watchers_expires ON active_watchers (expires);
+CREATE INDEX active_watchers_active_watchers_pres ON active_watchers (presentity_uri, event);
+CREATE INDEX active_watchers_updated_idx ON active_watchers (updated);
+CREATE INDEX active_watchers_updated_winfo_idx ON active_watchers (updated_winfo, presentity_uri);
+
 INSERT INTO version (table_name, table_version) values ('watchers','3');
 CREATE TABLE watchers (
     id SERIAL PRIMARY KEY NOT NULL,
@@ -62,10 +74,12 @@ CREATE TABLE xcap (
     source INTEGER NOT NULL,
     doc_uri VARCHAR(255) NOT NULL,
     port INTEGER NOT NULL,
-    CONSTRAINT xcap_account_doc_type_idx UNIQUE (username, domain, doc_type, doc_uri)
+    CONSTRAINT xcap_doc_uri_idx UNIQUE (doc_uri)
 );
 
-CREATE INDEX xcap_source_idx ON xcap (source);
+CREATE INDEX xcap_account_doc_type_idx ON xcap (username, domain, doc_type);
+CREATE INDEX xcap_account_doc_type_uri_idx ON xcap (username, domain, doc_type, doc_uri);
+CREATE INDEX xcap_account_doc_uri_idx ON xcap (username, domain, doc_uri);
 
 INSERT INTO version (table_name, table_version) values ('pua','7');
 CREATE TABLE pua (
@@ -87,6 +101,12 @@ CREATE TABLE pua (
     contact VARCHAR(128) NOT NULL,
     remote_contact VARCHAR(128) NOT NULL,
     version INTEGER NOT NULL,
-    extra_headers TEXT NOT NULL
+    extra_headers TEXT NOT NULL,
+    CONSTRAINT pua_pua_idx UNIQUE (etag, tuple_id, call_id, from_tag)
 );
 
+CREATE INDEX pua_expires_idx ON pua (expires);
+CREATE INDEX pua_dialog1_idx ON pua (pres_id, pres_uri);
+CREATE INDEX pua_dialog2_idx ON pua (call_id, from_tag);
+CREATE INDEX pua_record_idx ON pua (pres_id);
+
